Class: GemChangelogDiff::Detector
- Inherits:
-
Object
- Object
- GemChangelogDiff::Detector
- Defined in:
- lib/gem_changelog_diff/detector.rb
Overview
Detects outdated gems by parsing bundle outdated --parseable output.
Constant Summary collapse
- PARSEABLE_REGEX =
/\A(\S+)\s+\(newest\s+([^,]+),\s+installed\s+([^,)]+)/
Instance Method Summary collapse
-
#detect ⇒ Array<OutdatedGem>
Runs bundle outdated and returns the list of outdated gems.
Instance Method Details
#detect ⇒ Array<OutdatedGem>
Runs bundle outdated and returns the list of outdated gems.
13 14 15 16 |
# File 'lib/gem_changelog_diff/detector.rb', line 13 def detect output = run_bundle_outdated parse(output) end |